@@ -349,7 +349,6 @@ sub new {
     $fh->seek(0, SEEK_SET);
 
     $sock = new IO::Socket::INET( Proto     => "tcp",
-				  LocalPort => &Socket::INADDR_ANY(),
                                   Listen    => 1);
 
     unless (defined $sock) {
@@ -359,7 +358,7 @@ sub new {
     }    
 
     $container->ctcp('DCC SEND', $nick, $filename, 
-                     unpack("N",inet_aton(hostname())),
+                     unpack("N",inet_aton($container->hostname())),
 		     $sock->sockport(), $size);
 
     $sock->autoflush(1);
@@ -518,7 +517,6 @@ sub new {
         # we're initiating
 
         $sock = new IO::Socket::INET( Proto     => "tcp",
-				      LocalPort => &Socket::INADDR_ANY(),
                                       Listen    => 1);
 	
         unless (defined $sock) {
@@ -528,8 +526,9 @@ sub new {
 
 	$sock->autoflush(1);
 
-        $container->ctcp('DCC CHAT', $nick, 'chat',  
-                         unpack("N",inet_aton(hostname)), $sock->sockport());
+        $container->ctcp('DCC CHAT', $nick, 'chat',
+                         unpack("N",inet_aton($container->hostname)),
+						        $sock->sockport());
 
 	$self = {
 	    _bin        =>  0,      # Bytes we've recieved thus far
@@ -717,10 +716,10 @@ sub parse {
     $self->{_parent}->{_parent}->handler(Net::IRC::Event->
 					 new('dcc_open',
 					     $self->{_parent}->{_nick},
-					     $self->{_parent}->{_sock},
+					     $self->{_parent}->{_socket},
 					     $self->{_parent}->{_type},
 					     $self->{_parent}->{_type},
-					     $self->{_parent}->{_sock})
+					     $self->{_parent}->{_socket})
 					 );
 }
 
